@@ -1,5 +1,5 @@
 /* GMM (C) 2018 Stephane Charette <stephanecharette@gmail.com>
- * $Id: TabCanvas.cpp 2695 2018-12-10 16:00:12Z stephane $
+ * $Id: TabCanvas.cpp 2710 2019-01-25 15:41:56Z stephane $
  */
 
 #include "GMM.hpp"
@@ -890,9 +890,39 @@ void TabCanvas::read_all_mc_files(void)
 	 *		PPP is the 3-digit package number.
 	 */
 
-	// note how index starts at 1, not zero, since index zero is the summary file
-	for (int package_index = 1; package_index <= 999; package_index ++)
+	 /* Keep track of all the numbers we need to check.  The current package value must be last in that
+	  * list so that if the package already exists, then we'll retain the values and append the package.
+	  */
+	std::list<int> packages;
+	for (int idx = 1; idx <= 999; idx ++) // note how index starts at 1, not zero, since index zero is the summary file
 	{
+		packages.push_back(idx);
+	}
+	// the current package needs to be the last one we check, so place it at the very end of the list
+	packages.remove(current_pkg);
+	packages.push_back(current_pkg);
+
+	bool need_to_clear_out_old_package_values = true;
+
+	while (packages.empty() == false)
+	{
+		auto iter = packages.begin();
+		const int package_index = *iter;
+		packages.erase(iter);
+
+		if (need_to_clear_out_old_package_values)
+		{
+			// we're starting to read a new package, so clear out the package-specific values
+			for (size_t idx = 0; idx < number_of_buckets; idx++)
+			{
+				pkg_moisture_bucket[idx] = 0;
+			}
+			pkg_doubles.clear();
+			pkg_sum = 0.0;
+			pkg_std_dev = 0.0;
+			need_to_clear_out_old_package_values = false;
+		}
+
 		std::stringstream filename_ss;
 		filename_ss
 			<< current_kiln << "_"
@@ -907,14 +937,7 @@ void TabCanvas::read_all_mc_files(void)
 			continue;
 		}
 
-		// we're starting to read a new package, so clear out the package-specific values
-		for (size_t idx = 0; idx < number_of_buckets; idx++)
-		{
-			pkg_moisture_bucket[idx] = 0;
-		}
-		pkg_doubles.clear();
-		pkg_sum = 0.0;
-		pkg_std_dev = 0.0;
+		need_to_clear_out_old_package_values = true;
 
 		const std::string filename = file.getFullPathName().toStdString();
 		LOG_MSG("prefix=" << prefix << ": importing all existing values from " << filename);
